@@ -489,25 +489,31 @@ def html_nodes_text(XPATH_list):
     return text_list
 
 
-def console(data):
+def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True):
     """
-    Need to change colors to unwrap annotations for testing
-    需要更换颜色自行解开注释进行测试
-    :param data: Type == any
-    :return: data
+    :param self:
+    :param args:
+    :param sep:
+    :param end:
+    :param file:
+    :param color: if model == True --> color = '黄色'
+                  if model == False --> color = 'Fore.YELLOW'
+    :return:
     """
-    #     print(Fore.YELLOW + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTWHITE_EX + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTRED_EX + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTMAGENTA_EX + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTGREEN_EX + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTCYAN_EX + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTBLUE_EX + '人生苦短，我用Python！')
-    #     print(Fore.CYAN + '人生苦短，我用Python！')
-    #     print(Fore.LIGHTYELLOW_EX + '人生苦短，我用Python！')
-    #     print(Fore.RED + '人生苦短，我用Python！')
-    #     print(Fore.BLUE + '人生苦短，我用Python！')
-    #     print(Fore.GREEN + '人生苦短，我用Python！')
-    #     print(Fore.MAGENTA + '人生苦短，我用Python！')
-    #     print(Fore.RESET + '人生苦短，我用Python！')
-    print(Fore.LIGHTYELLOW_EX + f'{data}')
+    dic = {
+        '黄色': 'Fore.YELLOW', '+黄色': 'Fore.LIGHTYELLOW_EX',
+        '红色': 'Fore.RED', '+红色': 'Fore.LIGHTRED_EX',
+        '青色': 'Fore.CYAN', '+青色': 'Fore.LIGHTCYAN_EX',
+        '绿色': 'Fore.GREEN', '+绿色': 'Fore.LIGHTGREEN_EX',
+        '蓝色': 'Fore.BLUE', '+蓝色': 'Fore.LIGHTBLUE_EX',
+        '黑色': 'Fore.BLACK', '+黑色': 'Fore.LIGHTBLACK_EX',
+        '品红色': 'Fore.MAGENTA', '+白色': 'Fore.LIGHTWHITE_EX'
+    }
+    if color != None:
+        if model != False:
+            color = eval(dic[color])
+        else:
+            color = eval(color)
+    else:
+        color = Fore.LIGHTYELLOW_EX
+    print(color + self, *args, sep=sep, end=end, file=file)
